<?php

namespace Drupal\group_sites\Cache;

use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\Cache\Context\CacheContextInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\group_sites\GroupSitesAdminModeInterface;

/**
 * Defines a cache context for caching based on admin mode status.
 *
 * Cache context ID: 'user.in_group_sites_admin_mode'.
 */
class GroupSitesAdminModeCacheContext implements CacheContextInterface {

  /**
   * Constructs a new GroupMembershipPermissionsCacheContext class.
   *
   * @param \Drupal\group_sites\GroupSitesAdminModeInterface $adminMode
   *   The admin mode service.
   * @param \Drupal\Core\Session\AccountProxyInterface $currentUser
   *   The current user.
   */
  public function __construct(
    protected GroupSitesAdminModeInterface $adminMode,
    protected AccountProxyInterface $currentUser
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function getLabel() {
    return new TranslatableMarkup('User is in group sites admin mode');
  }

  /**
   * {@inheritdoc}
   */
  public function getContext() {
    return $this->adminMode->isActive() ? 'active' : 'inactive';
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheableMetadata() {
    return (new CacheableMetadata())->setCacheTags(['group_sites:admin_mode:' . $this->currentUser->id()]);
  }

}
